package com.caimei.controller;

import com.alibaba.fastjson.JSONObject;
import com.caimei.model.ResponseJson;
import com.caimei.model.vo.AuthVo;
import com.caimei.model.vo.BrandVo;
import com.caimei.service.AuthService;
import com.github.pagehelper.PageInfo;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiImplicitParam;
import io.swagger.annotations.ApiImplicitParams;
import io.swagger.annotations.ApiOperation;
import lombok.RequiredArgsConstructor;
import lombok.extern.slf4j.Slf4j;
import org.springframework.web.bind.annotation.*;

import java.util.List;
import java.util.Map;

/**
 * 供应商API
 *
 * @author : Aslee
 * @date : 2021/5/11
 */
@Api(tags = "品牌授权API")
@Slf4j
@RestController
@RequiredArgsConstructor
@RequestMapping("/auth")
public class AuthApi {

    private final AuthService authService;

    /**
     * 授权列表
     */
    @ApiOperation("授权列表")
    @ApiImplicitParams({
            @ApiImplicitParam(name = "listType", required = false, value = "列表类型：1授权列表，2授权审核列表"),
            @ApiImplicitParam(name = "authUserId", required = true, value = "供应商用户id"),
            @ApiImplicitParam(name = "authParty", required = false, value = "授权机构"),
            @ApiImplicitParam(name = "status", required = false, value = "上线状态：0已下线，1已上线，2待上线"),
            @ApiImplicitParam(name = "auditStatus", required = false, value = "审核状态:0审核未通过，1审核通过，2待审核"),
            @ApiImplicitParam(name = "lowerAuditStatus", required = false, value = "商品信息审核状态:0未完成审核，1已完成审核"),
            @ApiImplicitParam(name = "pageNum", required = false, value = "第几页"),
            @ApiImplicitParam(name = "pageSize", required = false, value = "一页多少条")
    })
    @GetMapping("/list")
    public ResponseJson<PageInfo<AuthVo>> getAuthList(Integer listType, Integer authUserId, String authParty, Integer status, Integer auditStatus, Integer lowerAuditStatus,
                                                      @RequestParam(value = "pageNum", defaultValue = "1") Integer pageNum,
                                                      @RequestParam(value = "pageSize", defaultValue = "10") Integer pageSize) {
        return authService.getAuthList(listType, authUserId, authParty, status, auditStatus, lowerAuditStatus, pageNum, pageSize);
    }
    /**
     * 更新授权状态
     */
    @ApiOperation("更新授权状态")
    @ApiImplicitParam(name = "params", value = "authId:授权id;status:授权状态:0停用 1启用;", required = true)
    @PostMapping("/update/status")
    public ResponseJson updateAuthStatus(@RequestBody Map<String,Integer> params) {
        Integer authId = params.get("authId");
        Integer status = params.get("status");
        return authService.updateAuthStatus(authId, status);
    }

    /**
     * 删除授权
     */
    @ApiOperation("删除授权")
    @ApiImplicitParam(name = "params", value = "authId:授权id", required = true)
    @PostMapping("/delete")
    public ResponseJson deleteAuth(@RequestBody Map<String,Integer> params) {
        Integer authId = params.get("authId");
        return authService.deleteAuth(authId);
    }

    /**
     * 添加/编辑授权
     */
    @ApiOperation("添加/编辑授权")
    @ApiImplicitParam(name = "params", value = "authId:授权id;authUserId:供应商用户id;authParty:授权机构;createBy:创建人id", required = true)
    @PostMapping("/save")
    public ResponseJson saveAuth(@RequestBody String params) {
        JSONObject paramsMap = JSONObject.parseObject(params);
        Integer authId = paramsMap.getInteger("authId");
        Integer authUserId = paramsMap.getInteger("authUserId");
        String authParty = paramsMap.getString("authParty");
        Integer createBy = paramsMap.getInteger("createBy");
        return authService.saveAuth(authId, authUserId, authParty, createBy);
    }


    /**
     * 审核品牌授权
     */
    @ApiOperation("审核品牌授权")
    @ApiImplicitParam(name = "params", value = "authId:授权id;auditStatus:审核状态：0审核未通过，1审核通过，2待审核;invalidReason:审核不通过原因;auditBy:审核人用户id", required = true)
    @PostMapping("/audit")
    public ResponseJson auditAuth(@RequestBody String params) {
        JSONObject paramsMap = JSONObject.parseObject(params);
        Integer authId = paramsMap.getInteger("authId");
        Integer auditStatus = paramsMap.getInteger("auditStatus");
        String invalidReason = paramsMap.getString("invalidReason");
        Integer auditBy = paramsMap.getInteger("auditBy");
        return authService.auditAuth(authId, auditStatus, invalidReason, auditBy);
    }
}
