package com.caimei.service;

import com.caimei.model.ResponseJson;
import com.caimei.model.dto.ProductSaveDto;
import com.caimei.model.vo.ProductFormVo;
import com.caimei.model.vo.ProductListVo;
import com.github.pagehelper.PageInfo;

import java.io.IOException;
import java.util.List;

/**
 * Description
 *
 * @author : Aslee
 * @date : 2021/5/17
 */
public interface AuthProductService {

    /**
     * 授权商品列表
     *
     *
     * @param listType      列表类型：1商品列表，2商品审核列表
     * @param authId        授权id
     * @param productName   商品名称
     * @param snCode        商品SN码
     * @param auditStatus   审核状态:0审核未通过，1审核通过，2待审核
     * @param pageNum       第几页
     * @param pageSize      一页多少条
     * @return  ProductListVo
     */
    ResponseJson<PageInfo<ProductListVo>> getProductList(Integer listType, Integer authId, String productName, String snCode, Integer auditStatus, Integer pageNum, Integer pageSize);

    /**
     * 更新授权商品状态
     * @param productId     授权商品id
     * @param status        上线状态：0已下线，1已上线，2待上线
     * @return  ResponseJson
     */
    ResponseJson updateProductStatus(Integer productId, Integer status);

    /**
     * 删除授权商品
     * @param productId     授权商品Id
     * @return  ResponseJson
     */
    ResponseJson deleteProduct(Integer productId);

    /**
     * 添加/编辑授权商品
     * @param productSaveDto {
     *                   productId              授权商品id
     *                   authId                 授权id
     *                   productName            商品名称
     *                   snCode                 商品SN码
     *                   productImage           商品图片
     *                   certificateImage       授权牌照
     *                   status                 上线状态：0已下线，1已上线，2待上线
     *                   createBy               创建人id
     *                   paramList              商品参数列表
     * }
     * @return ResponseJson
     */
    ResponseJson saveProduct(ProductSaveDto productSaveDto) throws IOException;

    /**
     * 获取授权商品回显数据
     * @param productId     商品id
     * @return  ProductFormVo
     */
    ResponseJson<ProductFormVo> getProductFormData(Integer productId);

    /**
     * 根据品牌授权id获取商品id列表
     * @param authId 授权id
     * @return  Integer
     */
    List<Integer> getProductIdsByAuthId(Integer authId);

    /**
     * 更新所有商品的水印图片
     * @return  ResponseJson
     */
    ResponseJson updateAllWaterMark();

    /**
     * 审核商品
     *
     * @param productId         商品id
     * @param auditStatus       审核状态
     * @param invalidReason     审核不通过原因
     * @param auditBy           审核人用户id
     * @return ResponseJson
     */
    ResponseJson auditProduct(Integer productId, Integer auditStatus, String invalidReason, Integer auditBy);
}
