package com.caimei.service;

import com.caimei.model.ResponseJson;
import com.caimei.model.vo.AuthVo;
import com.github.pagehelper.PageInfo;

/**
 * Description
 *
 * @author : Aslee
 * @date : 2021/5/11
 */
public interface AuthService {

    /**
     * 授权列表
     *
     * @param listType   列表类型：1授权列表，2授权审核列表
     * @param authUserId 供应商用户id
     * @param authParty  授权机构
     * @param status    上线状态：0已下线，1已上线，2待上线
     * @param auditStatus  审核状态:0审核未通过，1审核通过，2待审核
     * @param lowerAuditStatus  商品信息审核状态:0未完成审核，1已完成审核
     * @param pageNum    第几页
     * @param pageSize   一页多少条
     * @return AuthVo
     */
    ResponseJson<PageInfo<AuthVo>> getAuthList(Integer listType, Integer authUserId, String authParty, Integer status, Integer auditStatus, Integer lowerAuditStatus, Integer pageNum, Integer pageSize);

    /**
     * 更新授权状态
     *
     * @param authId 授权id
     * @param status 授权状态:0停用 1启用
     * @return ResponseJson
     */
    ResponseJson updateAuthStatus(Integer authId, Integer status);

    /**
     * 删除授权
     * @param authId    授权id
     * @return  ResponseJson
     */
    ResponseJson deleteAuth(Integer authId);

    /**
     * 添加/编辑授权
     *
     * @param authId            授权id
     * @param authUserId        供应商用户id
     * @param authParty         授权机构
     * @param createBy          创建人id
     * @return  ResponseJson
     */
    ResponseJson saveAuth(Integer authId, Integer authUserId, String authParty, Integer createBy);

    /**
     * 审核品牌授权
     *
     * @param authId            授权id
     * @param auditStatus       审核状态
     * @param invalidReason     审核不通过原因
     * @param auditBy           审核人用户id
     * @return ResponseJson
     */
    ResponseJson auditAuth(Integer authId, Integer auditStatus, String invalidReason, Integer auditBy);
}
