package com.caimei.service;

import com.caimei.model.ResponseJson;
import com.caimei.model.dto.ShopInfoDto;
import com.caimei.model.vo.*;
import com.github.pagehelper.PageInfo;
import org.springframework.web.multipart.MultipartFile;

import java.util.List;

/**
 * Description
 *
 * @author : Aslee
 * @date : 2021/5/11
 */
public interface ShopService {
    /**
     * 供应商列表数据
     *
     *
     * @param listType  列表类型：1供应商列表，2审核列表
     * @param shopName  供应商名称
     * @param shopType  供应商类型：1品牌方，2代理商
     * @param brandId   所属品牌Id
     * @param mobile    手机号
     * @param linkMan   联系人
     * @param lowerAuditStatus  下级审核状态,0未完成审核，1已完成审核
     * @param pageNum   第几页
     * @param pageSize  一页多少条
     * @return PageInfo<ShopVo>
     */
    ResponseJson<PageInfo<ShopListVo>> getShopList(Integer listType, String shopName, Integer shopType, Integer brandId, String mobile, String linkMan, Integer lowerAuditStatus, Integer pageNum, Integer pageSize);

    /**
     * 更新供应商状态
     * @param authUserId    供应商用户id
     * @param status    供应商状态
     * @return ResponseJson
     */
    ResponseJson updateShopStatus(Integer authUserId, Integer status);

    /**
     * 重置供应商密码
     * @param authUserId    供应商用户id
     * @return ResponseJson
     */
    ResponseJson resetShopPassword(Integer authUserId);

    /**
     * 上传文件
     *
     * @param authUserId 供应商用户id
     * @param brandId :品牌id
     * @param file       上传文件
     * @return
     */
    ResponseJson<FileVo> uploadFile(Integer authUserId, Integer brandId, MultipartFile file);

    /**
     * 添加供应商
     *  @param shopSaveDto {
     *                    shopType           供应商类型：1代理商，2品牌方
     *                    brandId            品牌id
     *                    shopName           供应商名称
     *                    mobile             手机号
     *                    linkMan            联系人
     *                    countryId          产地国家id
     *                    brandAuthLogo      品牌授权logo
     *                    shopStatus         供应商状态：0停用 1启用
     *                    securityLink       官网认证链接
     *                    statementType      代理声明类型：1弹窗 2链接 3图片 4文件（.doc .ppt .pdf）
     *                    statementContent   声明弹窗内容
     *                    statementLink      声明链接
     *                    statementImage     声明图片
     *                    statementFileId    声明文件id
     *                    createBy           创建人用户id
     *                    }
     * @param shopInfoList
     */
    ResponseJson saveShop(Integer authUserId, Integer shopType, String shopName, String mobile, String linkMan, Integer shopStatus, Integer createBy, List<ShopInfoDto> shopInfoList);

    /**
     * 获取供应商回显数据
     * @param authUserId 供应商用户id
     * @return  ShopVo
     */
    ResponseJson<ShopFormVo> getShopFormData(Integer authUserId);

    /**
     * 根据供应商用户id删除代理声明文件
     */
    void deleteFile(Integer authUserId,Integer brandId);

    /**
     * 品牌列表
     * @param type 1品牌方品牌列表，2代理商品牌列表
     * @param authUserId    供应商用户id
     * @return AuthVo
     */
    ResponseJson<List<BrandVo>> getBrandList(Integer type, Integer authUserId);

    /**
     * 产地国家列表
     * @return CountryVo
     */
    ResponseJson<List<CountryVo>> getCountryList();
}
