package com.caimei.service.impl;

import com.caimei.config.FastDfsClient;
import com.caimei.mapper.AuthProductMapper;
import com.caimei.model.ResponseJson;
import com.caimei.model.dto.ProductSaveDto;
import com.caimei.model.po.ProductParamPo;
import com.caimei.model.po.ProductPo;
import com.caimei.model.vo.ProductFormVo;
import com.caimei.model.vo.ProductListVo;
import com.caimei.service.AuthProductService;
import com.caimei.utils.Base64Util;
import com.caimei.utils.ImageUtils;
import com.github.pagehelper.PageHelper;
import com.github.pagehelper.PageInfo;
import lombok.extern.slf4j.Slf4j;
import org.apache.commons.lang3.StringUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.beans.factory.annotation.Value;
import org.springframework.core.io.ClassPathResource;
import org.springframework.stereotype.Service;
import org.springframework.web.multipart.MultipartFile;

import javax.annotation.Resource;
import javax.imageio.ImageIO;
import java.awt.*;
import java.io.File;
import java.io.IOException;
import java.io.InputStream;
import java.util.Date;
import java.util.List;
import java.util.UUID;

/**
 * Description
 *
 * @author : Aslee
 * @date : 2021/5/17
 */
@Slf4j
@Service
public class AuthProductServiceImpl implements AuthProductService {

    @Resource
    private AuthProductMapper authProductMapper;

    @Autowired
    private FastDfsClient client;

    @Value("${caimei.imageDomain}")
    private String imageDomain;

    @Override
    public ResponseJson<PageInfo<ProductListVo>> getProductList(Integer listType, Integer authId, String productName, String snCode, Integer auditStatus, Integer pageNum, Integer pageSize) {
        if (null == authId) {
            return ResponseJson.error("参数异常，请输入授权id", null);
        }
        listType = null == listType ? 1 : listType;
        PageHelper.startPage(pageNum, pageSize);
        List<ProductListVo> productList = authProductMapper.getProductList(listType, authId, productName, snCode, auditStatus);
        PageInfo<ProductListVo> pageData = new PageInfo<>(productList);
        return ResponseJson.success(pageData);
    }

    @Override
    public ResponseJson updateProductStatus(Integer productId, Integer status) {
        if (productId == null) {
            return ResponseJson.error("请输入用户id");
        }
        if (status == null) {
            return ResponseJson.error("请输入要更新的状态值");
        } else if (status != 0 && status != 1) {
            return ResponseJson.error("状态值只能为0或1");
        }
        authProductMapper.updateProductStatusByProductId(productId, status);
        if (status == 0) {
            return ResponseJson.success("下线授权商品成功");
        } else {
            return ResponseJson.success("上线授权商品成功");
        }
    }

    @Override
    public ResponseJson deleteProduct(Integer productId) {
        if (null == productId) {
            return ResponseJson.error("参数异常，请输入授权商品id");
        }
        // 删除商品
        authProductMapper.deleteProductByProductId(productId);
        // 删除商品参数
        authProductMapper.deleteParamsByProductId(productId);
        return ResponseJson.success("删除授权商品成功");
    }

    @Override
    public ResponseJson saveProduct(ProductSaveDto productSaveDto) throws IOException {
        Integer productId = productSaveDto.getProductId();
        Integer authId = productSaveDto.getAuthId();
        Integer brandId = productSaveDto.getBrandId();
        String productName = productSaveDto.getProductName();
        String snCode = productSaveDto.getSnCode();
        String productImage = productSaveDto.getProductImage();
        String certificateImage = productSaveDto.getCertificateImage();
        Integer createBy = productSaveDto.getCreateBy();
        List<ProductParamPo> paramList = productSaveDto.getParamList();
        if (null == authId) {
            return ResponseJson.error("参数异常，请输入授权id", null);
        }
        if (null == brandId) {
            return ResponseJson.error("参数异常，请输入品牌id", null);
        }
        if (StringUtils.isBlank(productName)) {
            return ResponseJson.error("参数异常，请输入商品名称", null);
        }
        if (StringUtils.isBlank(snCode)) {
            return ResponseJson.error("参数异常，请输入商品SN码", null);
        }
        Integer productIdBySnCode = authProductMapper.getProductIdBySnCode(snCode);
        if (null != productIdBySnCode && !productIdBySnCode.equals(productId)) {
            return ResponseJson.error("参数异常，该商品SN码已存在，请重新输入", null);
        }
        if (StringUtils.isBlank(productImage)) {
            return ResponseJson.error("参数异常，请上传商品图片", null);
        }
        if (StringUtils.isBlank(certificateImage)) {
            return ResponseJson.error("参数异常，请上传授权牌照", null);
        }
        if (null == paramList || paramList.size() <= 0) {
            return ResponseJson.error("参数异常，商品参数列表不能为空", null);
        }
        // 是否为添加操作
        boolean insertFlag = null == productId;
        /*
            组装商品数据
         */
        ProductPo product = new ProductPo();
        // 授权id
        product.setAuthId(authId);
        // 品牌id
        product.setBrandId(brandId);
        // 商品名称
        product.setProductName(productName);
        // sn码
        product.setSnCode(snCode);
        // 商品图片
        product.setProductImage(productImage);
        // 授权牌照
        product.setCertificateImage(certificateImage);
        // 商品信息保存后，上线状态默认为“待上线”，审核状态为“待审核”
        product.setStatus(2);
        product.setAuditStatus(2);
        if (insertFlag) {
            // 创建人id
            product.setCreateBy(createBy);
            // 创建时间
            product.setCreateTime(new Date());
            // 商品图片和授权牌照添加水印
            if (StringUtils.isNotBlank(product.getProductImage())) {
                //商品图片添加水印
                product.setPcImage(addWaterMark(product.getProductImage(), 1));
                product.setAppletsImage(addWaterMark(product.getProductImage(), 2));
            }
            if (StringUtils.isNotBlank(product.getCertificateImage())) {
                //授权牌照添加水印
                product.setPcCertificateImage(addWaterMark(product.getCertificateImage(), 1));
                product.setAppletsCertificateImage(addWaterMark(product.getCertificateImage(), 2));
            }
            // 插入授权商品
            authProductMapper.insertProduct(product);
        } else {
            // 商品id
            product.setProductId(productId);
            ProductPo productImages = authProductMapper.getImageByProductId(productId);
            boolean updateImageFlag = (StringUtils.isNotBlank(product.getProductImage()) && !product.getProductImage().equals(productImages.getProductImage())) || (StringUtils.isEmpty(productImages.getPcImage()) || StringUtils.isEmpty(productImages.getAppletsImage()));
            if (updateImageFlag) {
                //商品图片添加水印
                product.setPcImage(addWaterMark(product.getProductImage(), 1));
                product.setAppletsImage(addWaterMark(product.getProductImage(), 2));
            }
            updateImageFlag = (StringUtils.isNotBlank(product.getCertificateImage()) && !product.getCertificateImage().equals(productImages.getCertificateImage())) || (StringUtils.isEmpty(productImages.getPcCertificateImage()) || StringUtils.isEmpty(productImages.getPcCertificateImage()));
            if (updateImageFlag) {
                //授权牌照添加水印
                product.setPcCertificateImage(addWaterMark(product.getCertificateImage(), 1));
                product.setAppletsCertificateImage(addWaterMark(product.getCertificateImage(), 2));
            }
            // 更新授权商品
            authProductMapper.updateProductByProductId(product);
        }
        // 删除商品参数
        authProductMapper.deleteParamsByProductId(product.getProductId());
        // 保存商品参数
        paramList.forEach(param->{
            if (StringUtils.isNotBlank(param.getParamName()) && StringUtils.isNotBlank(param.getParamContent())) {
                authProductMapper.insertProductParam(product.getProductId(), param.getParamName(), param.getParamContent());
            }
        });
        return ResponseJson.success("保存授权商品成功");
    }

    private String addWaterMark(String image,Integer type) throws IOException {
        //type:1pc,2applets
        ClassPathResource classPathResource = new ClassPathResource("/images/pcWaterMark.png");
        InputStream inputStreamImg = classPathResource.getInputStream();
        Image pcWaterMarkImg = ImageIO.read(inputStreamImg);
        classPathResource = new ClassPathResource("/images/appletsWaterMark.png");
        inputStreamImg = classPathResource.getInputStream();
        Image appletsWaterMarkImg = ImageIO.read(inputStreamImg);
        String img = ImageUtils.markImageByIcon(type == 1 ? pcWaterMarkImg : appletsWaterMarkImg, image, null);
        String imagePath = null;
        if (StringUtils.isNotEmpty(img)) {
            MultipartFile imgFile = Base64Util.base64ToMultipart(img);
            if (null != imgFile) {
                imagePath = imageDomain + "/" + saveImage(imgFile);
            }
            log.info(">>>>>>>>>>>>>>>>水印图片上传成功:" + imagePath);
        }
        log.info(">>>>>>>>>>>>>>>>水印图片上传失败");
        return imagePath;
    }

    @Override
    public ResponseJson<ProductFormVo> getProductFormData(Integer productId) {
        if (null == productId) {
            return ResponseJson.error("参数异常，请输入商品id", null);
        }
        ProductFormVo productForm = authProductMapper.getProductFormByProductId(productId);
        if (null == productForm) {
            return ResponseJson.error("商品不存在", null);
        }
        List<ProductParamPo> paramList = authProductMapper.getParamsByProductId(productId);
        productForm.setParamList(paramList);
        return ResponseJson.success(productForm);
    }

    @Override
    public List<Integer> getProductIdsByAuthId(Integer authId) {
        return authProductMapper.getProductIdsByAuthId(authId);
    }



    private String saveImage(MultipartFile file) throws IOException {
        String originalFilename = file.getOriginalFilename();
        String randomUUID = UUID.randomUUID().toString();
        int index = originalFilename.lastIndexOf(".");
        String exet = originalFilename.substring(index);
        String filePath = "/mnt/newdatadrive/data/runtime/jar-instance/zplma/tempImage/";
        filePath += "\\" + randomUUID + exet;
        file.transferTo(new File(filePath));
        log.info(">>>>>>>>>>>>>>>>水印图片上传路径:" + filePath);
        return client.uploadFile(filePath);
    }

    @Override
    public ResponseJson updateAllWaterMark() {
        List<ProductPo> productList = authProductMapper.getAllImage();
        productList.forEach(product->{
            try {
                if (StringUtils.isNotEmpty(product.getProductImage())) {
                    //商品图片添加水印
                    product.setPcImage(addWaterMark(product.getProductImage(), 1));
                    product.setAppletsImage(addWaterMark(product.getProductImage(), 2));
                }
                if (StringUtils.isNotEmpty(product.getCertificateImage())) {
                    //授权牌照添加水印
                    product.setPcCertificateImage(addWaterMark(product.getCertificateImage(), 1));
                    product.setAppletsCertificateImage(addWaterMark(product.getCertificateImage(), 2));
                }
                // 更新授权商品
                authProductMapper.updateImageByProductId(product);
            } catch (IOException e) {
                e.printStackTrace();
            }
        });
        return ResponseJson.success("更新商品水印图片成功");
    }

    @Override
    public ResponseJson auditProduct(Integer productId, Integer auditStatus, String invalidReason, Integer auditBy) {
        if (productId == null) {
            return ResponseJson.error("请输入商品id");
        }
        if (auditStatus == null) {
            return ResponseJson.error("请输入审核结果");
        }
        if (auditStatus == 0 && StringUtils.isEmpty(invalidReason)) {
            return ResponseJson.error("请输入审核不通过的理由");
        }
        if (auditStatus == 0 && StringUtils.isEmpty(invalidReason)) {
            return ResponseJson.error("请输入审核不通过的理由");
        }
        if (auditBy == null) {
            return ResponseJson.error("请输入审核人用户id");
        }
        Date auditTime = new Date();
        authProductMapper.updateProductAuditStatus(productId, auditStatus, invalidReason, auditBy, auditTime);
        return ResponseJson.success("审核品牌授权成功");
    }
}
