CREATE TABLE `cm_brand_auth_user` (
                                                `authUserId` INT NOT NULL AUTO_INCREMENT,
                                                `name` VARCHAR(100) NULL COMMENT '账号名',
                                                `mobile` VARCHAR(20) NULL COMMENT '手机号',
                                                `password` VARCHAR(100) NULL COMMENT '密码',
                                                `linkMan` VARCHAR(30) NULL COMMENT '联系人',
                                                `userIdentity` INT NULL COMMENT '用户身份：1管理员，2供应商',
                                                `shopType` INT NULL COMMENT '供应商类型：1品牌方，2代理商',
                                                `createTime` DATETIME NULL COMMENT '创建时间',
                                                `createBy` INT NULL COMMENT '创建人Id',
                                                `status` INT NULL COMMENT '状态：0停用，1启用',
                                                PRIMARY KEY (`authUserId`))
    ENGINE = InnoDB
    DEFAULT CHARACTER SET = utf8
    COMMENT = '正品联盟后台管理员';

CREATE TABLE `cm_brand_auth_shop_info` (
                                                   `id` INT NOT NULL AUTO_INCREMENT,
                                                   `authUserId` INT NULL COMMENT '用户Id',
                                                   `brandId` INT NULL COMMENT '所属品牌Id',
                                                   `countryId` INT NULL COMMENT '产地国家id',
                                                   `securityLink` TEXT NULL COMMENT '官网认证链接',
                                                   `statementType` INT NULL COMMENT '代理声明类型：1弹窗，2链接，3图片，4文件',
                                                   `statementContent` TEXT NULL COMMENT '声明弹窗内容',
                                                   `statementLink` VARCHAR(255) NULL COMMENT '声明链接',
                                                   `statementImage` TEXT NULL COMMENT '声明图片',
                                                   PRIMARY KEY (`id`))
    ENGINE = InnoDB
    DEFAULT CHARACTER SET = utf8
    COMMENT = '正品联盟供应商信息';


INSERT INTO `cm_brand_auth_user` (`authUserId`, `name`, `password`, `userIdentity`, `status`) VALUES ('1', 'admin', '2A84213D52B1A2C85FB385A3DEDC789F', '1', '1');


ALTER TABLE `cm_brand_auth`
    ADD COLUMN `authUserId` INT NULL COMMENT '供应商用户id' AFTER `id`,
    ADD COLUMN `status` INT NULL COMMENT '上架状态：0已下架，1已上架' AFTER `authParty`;


ALTER TABLE `cm_brand_auth_product`
    ADD COLUMN `status` INT NULL COMMENT '上架状态：0下架，1上架' AFTER `certificateImage`,
    ADD COLUMN `brandId` INT NULL COMMENT '品牌id' AFTER `authId`,
    ADD COLUMN `pcImage` VARCHAR(255) NULL COMMENT 'pc添加水印商品图片' AFTER `image`,
    ADD COLUMN `appletsImage` VARCHAR(255) NULL COMMENT '小程序添加水印商品图片' AFTER `pcImage`,
    ADD COLUMN `pcCertificateImage` VARCHAR(255) NULL COMMENT 'pc添加水印授权牌照' AFTER `certificateImage`,
    ADD COLUMN `appletsCertificateImage` VARCHAR(255) NULL COMMENT '小程序添加水印授权牌照' AFTER `pcCertificateImage`;


CREATE TABLE `cm_brand_auth_file` (
                                      `id` INT NOT NULL AUTO_INCREMENT,
                                      `authUserId` INT NULL COMMENT '授权用户id',
                                      `brandId` INT NULL COMMENT '品牌id',
                                      `name` VARCHAR(300) NULL COMMENT '文件名称',
                                      `ossName` VARCHAR(300) NULL COMMENT 'oss存储名',
                                      `md5Hex` VARCHAR(32) NULL COMMENT '文件唯一标识',
                                      `uploadTime` DATETIME NULL COMMENT '上传时间',
                                      PRIMARY KEY (`id`))
    ENGINE = InnoDB
    DEFAULT CHARACTER SET = utf8
    COLLATE = utf8_bin
    COMMENT = '品牌授权代理声明文件';


# -----------------------------------------------------------------
ALTER TABLE `cm_brand_auth`
    DROP COLUMN `statementImage`,
    DROP COLUMN `statementLink`,
    DROP COLUMN `statementContent`,
    DROP COLUMN `statementType`,
    DROP COLUMN `agentName`,
    DROP COLUMN `agentFlag`,
    DROP COLUMN `securityLink`,
    DROP COLUMN `countryId`,
    DROP COLUMN `brandId`;

UPDATE `cm_brand_auth` set authUserId = 2,status = 1 where id = 1;
UPDATE `cm_brand_auth` set authUserId = 2,status = 1 where id between 3 and 55;
UPDATE `cm_brand_auth` set authUserId = 3,status = 1 where id = 2;

UPDATE `cm_brand_auth_product` set brandId = 144 where id = 1;
UPDATE `cm_brand_auth_product` set brandId = 39 where id = 2;
UPDATE `cm_brand_auth_product` set brandId = 204 where id between 3 and 62;

# ==================================正品联盟6月优化start===============================================
ALTER TABLE `cm_brand_auth`
    ADD COLUMN `auditStatus` INT NULL COMMENT '审核状态：0审核未通过，1审核通过，2待审核' AFTER `status`,
    ADD COLUMN `invalidReason` VARCHAR(255) NULL COMMENT '审核不通过原因' AFTER `auditStatus`,
    ADD COLUMN `auditBy` INT NULL COMMENT '审核人用户id' AFTER `createBy`,
    ADD COLUMN `auditTime` DATETIME NULL COMMENT '审核时间' AFTER `auditBy`,
    CHANGE COLUMN `status` `status` INT NULL  DEFAULT NULL COMMENT '上架状态：0已下线，1已上线，2待上线' ;

ALTER TABLE `cm_brand_auth_product`
    ADD COLUMN `auditStatus` INT NULL COMMENT '审核状态：0审核未通过，1审核通过，2待审核' AFTER `status`,
    ADD COLUMN `invalidReason` VARCHAR(255) NULL COMMENT '审核不通过原因' AFTER `auditStatus`,
    ADD COLUMN `auditBy` INT NULL DEFAULT NULL COMMENT '审核人用户id' AFTER `createBy`,
    ADD COLUMN `auditTime` DATETIME NULL COMMENT '审核时间' AFTER `auditBy`,
    CHANGE COLUMN `status` `status` INT NULL DEFAULT NULL COMMENT '上架状态：0下线，1上线，2待上线' ;

# ==================================正品联盟6月优化end===============================================


